@@ -6,6 +6,7 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
 import operator
+import unicodedata
 import weakref
 from collections import OrderedDict, deque
 from datetime import timedelta
@@ -21,7 +22,6 @@ from calibre.utils.icu import lower as icu_lower
 from calibre.utils.icu import primary_contains, primary_no_punc_contains, sort_key
 from calibre.utils.localization import canonicalize_lang, lang_map
 from calibre.utils.search_query_parser import ParseException, SearchQueryParser
-from polyglot.builtins import iteritems, string_or_bytes
 
 CONTAINS_MATCH = 0
 EQUALS_MATCH   = 1
@@ -174,7 +174,7 @@ class DateSearch:  # {{{
                     matches |= book_ids
             return matches
 
-        for k, relop in iteritems(self.operators):
+        for k, relop in self.operators.items():
             if query.startswith(k):
                 query = query[len(k):]
                 break
@@ -210,7 +210,7 @@ class DateSearch:  # {{{
                     field_count = query.count('/') + 1
 
         for v, book_ids in field_iter():
-            if isinstance(v, string_or_bytes):
+            if isinstance(v, (str, bytes)):
                 v = parse_date(v)
             if v is not None and relop(dt_as_local(v), qd, field_count):
                 matches |= book_ids
@@ -268,7 +268,7 @@ class NumericSearch:  # {{{
                 def relop(x, y):
                     return (x is not None)
         else:
-            for k, relop in iteritems(self.operators):
+            for k, relop in self.operators.items():
                 if query.startswith(k):
                     query = query[len(k):]
                     break
@@ -323,39 +323,60 @@ class NumericSearch:  # {{{
 # }}}
 
 
+nfc = partial(unicodedata.normalize, 'NFC')
+nfkc = partial(unicodedata.normalize, 'NFKC')
+nfkd = partial(unicodedata.normalize, 'NFKD')
+nfd = partial(unicodedata.normalize, 'NFD')
+
+
+def local_forms(x: str) -> set[str]:
+    x = icu_lower(x)
+    return {nfc(x), nfd(x), nfkc(x), nfkd(x)}
+
+
 class BooleanSearch:  # {{{
 
     def __init__(self):
-        self.local_no        = icu_lower(_('no'))
-        self.local_yes       = icu_lower(_('yes'))
-        self.local_unchecked = icu_lower(_('unchecked'))
-        self.local_checked   = icu_lower(_('checked'))
-        self.local_empty     = icu_lower(_('empty'))
-        self.local_blank     = icu_lower(_('blank'))
-        self.local_bool_values = {
-            self.local_no, self.local_unchecked, '_no', 'false', 'no', 'unchecked', '_unchecked',
-            self.local_yes, self.local_checked, 'checked', '_checked', '_yes', 'true', 'yes',
-            self.local_empty, self.local_blank, 'blank', '_blank', '_empty', 'empty'}
+        local_no = local_forms(_('No')) | local_forms(_('no'))
+        local_yes       = local_forms(_('Yes')) | local_forms(_('yes'))
+        local_unchecked = local_forms(_('unchecked'))
+        local_checked   = local_forms(_('checked'))
+        local_empty     = local_forms(_('empty'))
+        local_blank     = local_forms(_('blank'))
+
+        self.valid_bool_values = frozenset({
+            '_no', 'false', 'no', 'unchecked', '_unchecked',
+            'checked', '_checked', '_yes', 'true', 'yes',
+            'blank', '_blank', '_empty', 'empty',
+        } | local_no | local_yes | local_unchecked | local_checked | local_empty | local_blank)
+        self.no_and_unchecked = frozenset({
+            'unchecked', '_unchecked', 'no', '_no', 'false'} | local_no | local_unchecked)
+        self.no_and_unchecked_with_true = frozenset({
+            'unchecked', '_unchecked', 'no', '_no', 'true'} | local_no | local_unchecked)
+        self.yes_and_checked = frozenset({
+            'checked', '_checked', 'yes', '_yes', 'true'} | local_yes | local_checked)
+        self.empty_and_blank = frozenset({
+            'blank', '_blank', 'empty', '_empty', 'false'} | local_empty | local_blank)
 
     def __call__(self, query, field_iter, bools_are_tristate):
         matches = set()
-        if query not in self.local_bool_values:
+        if query not in self.valid_bool_values:
             raise ParseException(_('Invalid boolean query "{0}"').format(query))
         for val, book_ids in field_iter():
             val = force_to_bool(val)
             if not bools_are_tristate:
                 if val is None or not val:  # item is None or set to false
-                    if query in {self.local_no, self.local_unchecked, 'unchecked', '_unchecked', 'no', '_no', 'false'}:
+                    if query in self.no_and_unchecked:
                         matches |= book_ids
-                elif query in {self.local_yes, self.local_checked, 'checked', '_checked', 'yes', '_yes', 'true'}:
+                elif query in self.yes_and_checked:
                     matches |= book_ids
             elif val is None:
-                if query in {self.local_empty, self.local_blank, 'blank', '_blank', 'empty', '_empty', 'false'}:
+                if query in self.empty_and_blank:
                     matches |= book_ids
             elif not val:  # is not None and false
-                if query in {self.local_no, self.local_unchecked, 'unchecked', '_unchecked', 'no', '_no', 'true'}:
+                if query in self.no_and_unchecked_with_true:
                     matches |= book_ids
-            elif query in {self.local_yes, self.local_checked, 'checked', '_checked', 'yes', '_yes', 'true'}:
+            elif query in self.yes_and_checked:
                 matches |= book_ids
         return matches
 
@@ -388,7 +409,7 @@ class KeyPairSearch:  # {{{
             return found if valq == 'true' else candidates - found
 
         for m, book_ids in field_iter():
-            for key, val in iteritems(m):
+            for key, val in m.items():
                 if (keyq and not _match(keyq, (key,), keyq_mkind,
                                         use_primary_find_in_search=use_primary_find)):
                     continue
@@ -737,7 +758,7 @@ class Parser(SearchQueryParser):  # {{{
                 q = canonicalize_lang(query)
                 if q is None:
                     lm = lang_map()
-                    rm = {v.lower():k for k,v in iteritems(lm)}
+                    rm = {v.lower():k for k,v in lm.items()}
                     q = rm.get(query, query)
 
             if matchkind == CONTAINS_MATCH and q.lower() in {'true', 'false'}:
@@ -773,7 +794,7 @@ class Parser(SearchQueryParser):  # {{{
             if location in text_fields:
                 for val, book_ids in self.field_iter(location, current_candidates):
                     if val is not None:
-                        if isinstance(val, string_or_bytes):
+                        if isinstance(val, (str, bytes)):
                             val = (val,)
                         if _match(q, val, matchkind, use_primary_find_in_search=upf, case_sensitive=case_sensitive):
                             matches |= book_ids
@@ -866,7 +887,7 @@ class LRUCache:  # {{{
         return self.get(key)
 
     def __iter__(self):
-        return iteritems(self.item_map)
+        yield from self.item_map.items()
 # }}}
 
 
